<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 7/29/2014	ELL
// 
// 
	include ("check_session.php");
?>
<!DOCTYPE html>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Server Information | Breeze Website Builder</title>
<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
<script>
	window.parent.document.title = document.title;
</script>
</head>

<body id="workspace_body">
<?php
	$query = "SELECT VERSION()";
	$result = $bwb_dbh->query($query);
	$row = $result->fetch(PDO::FETCH_ASSOC);
	$version = $row['VERSION()'];
	if (strpos($version, "MariaDB") !== false)	{
		$logo = "MariaDB_Logo.png";
		$db_type = "MariaDB";
	}
	else	{
		$logo = "logo-mysql-110x57.png";
		$db_type = "MySQL";
	}
?>

	<center>
    <div style='width:600px; height:40px; background-color:#9999CC; padding-top:18px; border:thin black solid; font-size:20px; font-family:Arial, Helvetica, sans-serif; font-weight:bold;'><?php echo $db_type; ?> Version:
    <?php echo $version; ?>
    <img src="images/<?php echo $logo; ?>" style="margin-top:-18px;" alt="MySQL" />
    </div>
    </center><br />

<?php	
	phpinfo();
?>
</body>
</html>